IsSystem

Trait IsSystem 

pub trait IsSystem {
    // Required method
    fn is_system(&self) -> bool;
}
Determine if a parachain is a system parachain or not.

Required Methods

fn is_system(&self) -> bool

Returns true if a parachain is a system parachain, false otherwise.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors